@@ -70,6 +70,7 @@ struct Cell final : public MWAWCell {
   {
     setPosition(pos);
   }
+  Cell(Cell const &)=default;
   //! destructor
   ~Cell() final;
   //! the cell content
@@ -1084,7 +1085,7 @@ bool BeagleWksSSParser::readCellSheet(BeagleWksSSParserInternal::Cell &cell)
           break;
         case 5:
           format.m_format=MWAWCell::F_DATE;
-          format.m_DTFormat="%m/%d/%y:";
+          format.m_DTFormat="%m/%d/%y";
           break;
         case 6:
           switch (form & 0x7) {
