@@ -867,14 +867,12 @@ std::shared_ptr<ClarisWksStruct::DSET> ClarisWksDocument::readDSET(bool &complet
 
   if (sz < 16) return std::shared_ptr<ClarisWksStruct::DSET>();
   long endPos = entry.end();
-  input->seek(endPos, librevenge::RVNG_SEEK_SET);
-  if (long(input->tell()) != endPos) {
+  if (!input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("ClarisWksDocument::readDSET: file is too short\n"));
     return std::shared_ptr<ClarisWksStruct::DSET>();
   }
 
   ClarisWksStruct::DSET dset;
-  input->seek(pos+8, librevenge::RVNG_SEEK_SET);
   dset.m_size = sz;
   dset.m_numData = static_cast<int>(input->readULong(2));
 
@@ -889,7 +887,23 @@ std::shared_ptr<ClarisWksStruct::DSET> ClarisWksDocument::readDSET(bool &complet
     dset.m_textType = static_cast<int>(input->readULong(1));
     dset.m_flags[nFlags++] = static_cast<int>(input->readLong(1));
     break;
-  default:
+  default: {
+    // ( see libmwaw/discussion/help/thread/9c5816d751/ )
+    // I find some windows files (filetype==5) where this subzone is written in little endian
+    //
+    // more precisely, I found dataSz,headerSz,m_flags[2] stored as in little endian
+    //                 while m_size, m_flags[3], m_id are still stored as big endian
+    //   m_numData=0, m_flags[0|1]={ffff,0} so unsure about these fields
+    //
+    // normally, when filetype==5, we have m_size=64, m_headerSz=52,
+    // so first check if m_headerSz>m_size to decide if we must swap to little endian
+    input->seek(4, librevenge::RVNG_SEEK_CUR);
+    bool invertRead=static_cast<int>(input->readULong(2))>dset.m_size;
+    if (invertRead)
+      input->setReadInverted(true);
+    input->seek(-6, librevenge::RVNG_SEEK_CUR);
+
+    // now read the data
     dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2)); // normally -1
     dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2)); // the 0
     dset.m_dataSz = static_cast<int>(input->readULong(2));
@@ -899,11 +913,13 @@ std::shared_ptr<ClarisWksStruct::DSET> ClarisWksDocument::readDSET(bool &complet
       MWAW_DEBUG_MSG(("ClarisWksDocument::readDSET: invalid DSET\n"));
       return std::shared_ptr<ClarisWksStruct::DSET>();
     }
+    if (invertRead)
+      input->setReadInverted(false);
     break;
   }
+  }
   dset.m_flags[nFlags++] = static_cast<int>(input->readLong(2));
   dset.m_id = static_cast<int>(input->readULong(2));
-
   bool parsed = true;
   std::shared_ptr<ClarisWksStruct::DSET> res;
   switch (dset.m_fileType) {
@@ -2160,7 +2176,7 @@ bool ClarisWksDocument::readDataLinkList()
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     f.str("");
     f << "DataLink-" << i << ":";
-    if (zone.m_dataSize==66 || zone.m_dataSize==70) {
+    if (zone.m_dataSize==66 || zone.m_dataSize==70) { // find also 150 (probably 66+free space)
       int dim[2];
       for (auto &d: dim) d=int(input->readLong(2));
       if (dim[0]==-1) {
