@@ -490,6 +490,7 @@ struct Paragraph final : public MWAWParagraph {
   {
     for (auto &space : m_befAftSpacings) space=0;
   }
+  Paragraph(Paragraph const &)=default;
   //! destructor
   ~Paragraph() final;
   //! operator<<
@@ -1450,7 +1451,7 @@ bool FullWrtText::send(std::shared_ptr<FullWrtTextInternal::Zone> zone, MWAWColo
   font.m_font=MWAWFont(3,12);
   font.m_font.setColor(fontColor);
   FullWrtTextInternal::Paragraph ruler;
-  if (zone->m_zone->m_type==0x11 || zone->m_zone->m_type==0x12)
+  if (zone->m_zone->m_fileType==0x11 || zone->m_zone->m_fileType==0x12)
     ruler.setAlign(1);
 
   auto listBreaks = zone->getBreaksPosition();
@@ -1650,14 +1651,14 @@ bool FullWrtText::readTextData(FullWrtStruct::EntryPtr zone)
   long pos = zone->begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
-  bool knownZone = (zone->m_type >= 0xa && zone->m_type <= 0x14) || (zone->m_type == 0x18);
+  bool knownZone = (zone->m_fileType >= 0xa && zone->m_fileType <= 0x14) || (zone->m_fileType == 0x18);
 
   auto header = static_cast<int>(input->readULong(2));
   bool hasHeader = false;
   if (!knownZone && (header&0xFC00)) return false;
 
   std::shared_ptr<FullWrtTextInternal::Zone> text(new FullWrtTextInternal::Zone);
-  text->m_zoneType = (zone->m_type==0xa) ?
+  text->m_zoneType = (zone->m_fileType==0xa) ?
                      FullWrtTextInternal::Zone::Main : FullWrtTextInternal::Zone::Normal;
   text->m_zone = zone;
 
@@ -2470,7 +2471,7 @@ int FullWrtText::getHeaderFooterId(bool header, int page, int &numSimilar) const
   for (auto it : m_state->m_entryMap) {
     int id=it.first;
     auto zone=it.second;
-    if (!zone || !zone->m_zone || zone->m_zone->m_type!=type ||
+    if (!zone || !zone->m_zone || zone->m_zone->m_fileType!=type ||
         zone->m_pages[0]<page)
       continue;
     if (zone->m_pages[1]>=page)
