@@ -65,15 +65,20 @@ namespace HanMacWrdKParserInternal
 //! Internal: the state of a HanMacWrdKParser
 struct State {
   //! constructor
-  State() : m_zonesListBegin(-1), m_zonesMap(),
-    m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
+  State()
+    : m_zonesListBegin(-1)
+    , m_zonesMap()
+    , m_actPage(0)
+    , m_numPages(0)
+    , m_headerHeight(0)
+    , m_footerHeight(0)
   {
   }
 
   //! the list of zone begin
   long m_zonesListBegin;
   //! a map of entry: zoneId->zone
-  std::multimap<long,shared_ptr<HanMacWrdKZone> > m_zonesMap;
+  std::multimap<long,std::shared_ptr<HanMacWrdKZone> > m_zonesMap;
 
   int m_actPage /** the actual page */, m_numPages /** the number of page of the final document */;
   int m_headerHeight /** the header height if known */,
@@ -82,33 +87,28 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a HanMacWrdKParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(HanMacWrdKParser &pars, MWAWInputStreamPtr input, long zoneId) :
-    MWAWSubDocument(&pars, input, MWAWEntry()), m_id(zoneId) {}
+  SubDocument(HanMacWrdKParser &pars, MWAWInputStreamPtr const &input, long zoneId)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+    , m_id(zoneId) {}
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     if (m_id != sDoc->m_id) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
-
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   //! the subdocument id
@@ -125,7 +125,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type
     MWAW_DEBUG_MSG(("HanMacWrdKParserInternal::SubDocument::parse: unexpected document type\n"));
     return;
   }
-  HanMacWrdKParser *parser=dynamic_cast<HanMacWrdKParser *>(m_parser);
+  auto *parser=dynamic_cast<HanMacWrdKParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("HanMacWrdKParserInternal::SubDocument::parse: no listener\n"));
     return;
@@ -139,8 +139,11 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type
 ////////////////////////////////////////////////////////////
 // constructor/destructor + basic interface ...
 ////////////////////////////////////////////////////////////
-HanMacWrdKParser::HanMacWrdKParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state(), m_graphParser(), m_textParser()
+HanMacWrdKParser::HanMacWrdKParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
+  , m_graphParser()
+  , m_textParser()
 {
   init();
 }
@@ -178,7 +181,7 @@ bool HanMacWrdKParser::canSendTextAsGraphic(long id, long subId)
 
 bool HanMacWrdKParser::sendZone(long zId)
 {
-  MWAWPosition pos(MWAWVec2i(0,0), MWAWVec2i(0,0), librevenge::RVNG_POINT);
+  MWAWPosition pos(MWAWVec2f(0,0), MWAWVec2f(0,0), librevenge::RVNG_POINT);
   pos.setRelativePosition(MWAWPosition::Char);
   return m_graphParser->sendFrame(zId, pos);
 }
@@ -218,18 +221,18 @@ void HanMacWrdKParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void HanMacWrdKParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L)) throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr)) throw(libmwaw::ParseException());
   bool ok = true;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
 
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
-      std::vector<long> const &tokenIds = m_textParser->getTokenIdList();
+      auto const &tokenIds = m_textParser->getTokenIdList();
       m_graphParser->sendPageGraphics(tokenIds);
       m_textParser->sendMainText();
 
@@ -305,11 +308,10 @@ bool HanMacWrdKParser::createZones()
     return false;
 
   libmwaw::DebugStream f;
-  std::multimap<long,shared_ptr<HanMacWrdKZone> >::iterator it;
-  for (it = m_state->m_zonesMap.begin(); it !=m_state->m_zonesMap.end(); ++it)
-    readZone(it->second);
-  for (it = m_state->m_zonesMap.begin(); it !=m_state->m_zonesMap.end(); ++it) {
-    shared_ptr<HanMacWrdKZone> &zone = it->second;
+  for (auto it : m_state->m_zonesMap)
+    readZone(it.second);
+  for (auto it : m_state->m_zonesMap) {
+    std::shared_ptr<HanMacWrdKZone> &zone = it.second;
     if (!zone || !zone->valid() || zone->m_parsed)
       continue;
     f.str("");
@@ -320,7 +322,7 @@ bool HanMacWrdKParser::createZones()
 
   // retrieve the text type and pass information to text parser
   m_graphParser->prepareStructures();
-  std::map<long,int> idTypeMap = m_graphParser->getTextFrameInformations();
+  auto idTypeMap = m_graphParser->getTextFrameInformations();
   m_textParser->updateTextZoneTypes(idTypeMap);
 
   return true;
@@ -350,7 +352,7 @@ bool HanMacWrdKParser::readZonesList()
     seeDebZone.insert(debZone);
     long pos = debZone;
     input->seek(pos, librevenge::RVNG_SEEK_SET);
-    int numZones = int(input->readULong(1));
+    auto numZones = int(input->readULong(1));
     f.str("");
     f << "Entries(Zones):";
     f << "N=" << numZones << ",";
@@ -365,7 +367,7 @@ bool HanMacWrdKParser::readZonesList()
       val = int(input->readLong(1));
       if (val) f << "f" << i << "=" << val << ",";
     }
-    long ptr = long(input->readULong(4));
+    auto ptr = long(input->readULong(4));
     if (ptr != debZone) {
       MWAW_DEBUG_MSG(("HanMacWrdKParser::readZonesList: can not read the zone begin ptr\n"));
       f << "#ptr=" << std::hex << ptr << std::dec << ",";
@@ -373,7 +375,7 @@ bool HanMacWrdKParser::readZonesList()
       ascii().addNote(f.str().c_str());
       break;
     }
-    long nextPtr = long(input->readULong(4));
+    auto nextPtr = long(input->readULong(4));
     if (nextPtr) {
       f << "nextPtr=" << std::hex << nextPtr << std::dec;
       if (!input->checkPosition(nextPtr)) {
@@ -394,7 +396,7 @@ bool HanMacWrdKParser::readZonesList()
     for (int i = 0; i < numZones; i++) {
       pos = input->tell();
       f.str("");
-      shared_ptr<HanMacWrdKZone> zone(new HanMacWrdKZone(shared_ptr<libmwaw::DebugFile>(new libmwaw::DebugFile(MWAWInputStreamPtr()))));
+      std::shared_ptr<HanMacWrdKZone> zone(new HanMacWrdKZone(std::shared_ptr<libmwaw::DebugFile>(new libmwaw::DebugFile(MWAWInputStreamPtr()))));
       zone->m_type = int(input->readLong(2));
       val = int(input->readLong(2));
       if (val) f << "f0=" << val << ",";
@@ -410,7 +412,7 @@ bool HanMacWrdKParser::readZonesList()
       }
       else
         m_state->m_zonesMap.insert
-        (std::multimap<long,shared_ptr<HanMacWrdKZone> >::value_type(zone->m_id,zone));
+        (std::multimap<long,std::shared_ptr<HanMacWrdKZone> >::value_type(zone->m_id,zone));
       ascii().addDelimiter(input->tell(), '|');
       ascii().addPos(pos);
       ascii().addNote(f.str().c_str());
@@ -425,7 +427,7 @@ bool HanMacWrdKParser::readZonesList()
   return m_state->m_zonesMap.size();
 }
 
-bool HanMacWrdKParser::readZone(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKParser::readZone(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readZone: can not find the zone\n"));
@@ -437,13 +439,13 @@ bool HanMacWrdKParser::readZone(shared_ptr<HanMacWrdKZone> zone)
   long pos = zone->fileBeginPos();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(" << zone->name() << "):";
-  int n = int(input->readLong(2));
+  auto n = int(input->readLong(2));
   f << "n?=" << n << ",";
-  long val = long(input->readLong(2));
+  auto val = long(input->readLong(2));
   if (val) f << "unkn=" << val << ",";
 
-  long totalSz = long(input->readULong(4));
-  long dataSz = long(input->readULong(4));
+  auto totalSz = long(input->readULong(4));
+  auto dataSz = long(input->readULong(4));
   if (totalSz != dataSz+12 || !input->checkPosition(pos+totalSz)) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readZone: can not read the zone size\n"));
     f << "###";
@@ -542,16 +544,16 @@ bool HanMacWrdKParser::readPrintInfo(HanMacWrdKZone &zone)
   zone.m_parsed = true;
 
   f << zone.name() << "(A):PTR=" << std::hex << zone.fileBeginPos() << std::dec << ",";
-  float margins[4]; // L, T, R, B
-  int dim[4];
   long val;
   f << "margins?=[";
-  for (int i= 0; i < 4; i++) {
-    margins[i] = float(input->readLong(4))/65536.f;
-    f << margins[i] << ",";
+  float margins[4]; // L, T, R, B
+  for (auto &margin : margins) {
+    margin = float(input->readLong(4))/65536.f;
+    f << margin << ",";
   }
   f << "],";
-  for (int i = 0; i < 4; i++) dim[i]=int(input->readLong(2));
+  int dim[4];
+  for (auto &d : dim) d=int(input->readLong(2));
   f << "paper=[" << dim[1] << "x" << dim[0] << " " << dim[3] << "x" << dim[2] << "],";
   val = long(input->readULong(2));
   if (val != 1) f << "firstSectNumber=" << val << ",";
@@ -566,7 +568,7 @@ bool HanMacWrdKParser::readPrintInfo(HanMacWrdKZone &zone)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f.str("");
   f << zone.name() << "(B):";
-  long sz = long(input->readULong(4));
+  auto sz = long(input->readULong(4));
   if (sz < 0x78) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readPrintInfo: the print info data zone seems too short\n"));
     f << "###";
@@ -598,7 +600,7 @@ bool HanMacWrdKParser::readPrintInfo(HanMacWrdKZone &zone)
     paperSize = MWAWVec2i(dim[3]-dim[1],dim[2]-dim[0]);
   else if (usePrintInfo) {
     lTopMargin= MWAWVec2f(-float(info.paper().pos(0)[0]), -float(info.paper().pos(0)[1]));
-    rBotMargin=info.paper().pos(1) - info.page().pos(1);
+    rBotMargin= MWAWVec2f(info.paper().pos(1) - info.page().pos(1));
 
     // move margin left | top
     float decalX = lTopMargin.x() > 14 ? 14 : 0;
@@ -636,7 +638,7 @@ bool HanMacWrdKParser::readPrintInfo(HanMacWrdKZone &zone)
 }
 
 // a small unknown zone: link to table, frame?
-bool HanMacWrdKParser::readFramesUnkn(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKParser::readFramesUnkn(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readFramesUnkn: called without any zone\n"));
@@ -655,7 +657,7 @@ bool HanMacWrdKParser::readFramesUnkn(shared_ptr<HanMacWrdKZone> zone)
 
   f << zone->name() << ":PTR=" << std::hex << zone->fileBeginPos() << std::dec << ",";
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  int N= static_cast<int>(input->readLong(2)); // always find val=0, so :-~
+  auto N= static_cast<int>(input->readLong(2)); // always find val=0, so :-~
   f << "N?=" << N << ",";
   long expectedSz = N*6+2;
   if (expectedSz != dataSz && expectedSz+1 != dataSz) {
@@ -671,7 +673,7 @@ bool HanMacWrdKParser::readFramesUnkn(shared_ptr<HanMacWrdKZone> zone)
     f << zone->name() << "-" << i << ":";
     long id = input->readLong(4);
     f << "id=" << std::hex << id << std::dec << ",";
-    int type = static_cast<int>(input->readLong(2));
+    auto type = static_cast<int>(input->readLong(2));
     switch (type) {
     case 4:
       f << "textbox,";
@@ -705,7 +707,7 @@ bool HanMacWrdKParser::readFramesUnkn(shared_ptr<HanMacWrdKZone> zone)
 }
 
 // a unknown zone
-bool HanMacWrdKParser::readZone6(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKParser::readZone6(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readZone6: called without any zone\n"));
@@ -728,7 +730,7 @@ bool HanMacWrdKParser::readZone6(shared_ptr<HanMacWrdKZone> zone)
   // no sure, checkme
   for (int st = 0; st < 2; st++) {
     pos = input->tell();
-    long sz = long(input->readULong(4));
+    auto sz = long(input->readULong(4));
     if (sz<0 || pos+sz+4 > dataSz) {
       MWAW_DEBUG_MSG(("HanMacWrdKParser::readZone6: zone%d ptr seems bad\n", st));
       return false;
@@ -749,7 +751,7 @@ bool HanMacWrdKParser::readZone6(shared_ptr<HanMacWrdKZone> zone)
 }
 
 // a small unknown zone
-bool HanMacWrdKParser::readZone8(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKParser::readZone8(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readZone8: called without any zone\n"));
@@ -782,7 +784,7 @@ bool HanMacWrdKParser::readZone8(shared_ptr<HanMacWrdKZone> zone)
 }
 
 // a small unknown zone
-bool HanMacWrdKParser::readZonea(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKParser::readZonea(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readZonea: called without any zone\n"));
@@ -884,7 +886,7 @@ bool HanMacWrdKParser::readZoneb(HanMacWrdKZone &zone)
 }
 
 // a small unknown zone
-bool HanMacWrdKParser::readZonec(shared_ptr<HanMacWrdKZone> zone)
+bool HanMacWrdKParser::readZonec(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::readZonec: called without any zone\n"));
@@ -916,8 +918,7 @@ bool HanMacWrdKParser::readZonec(shared_ptr<HanMacWrdKZone> zone)
   }
   // two similar number: selection?
   long sel[2];
-  for (int j = 0; j < 2; j++)
-    sel[j] = input->readLong(4);
+  for (auto &s : sel) s = input->readLong(4);
   if (sel[0] || sel[1]) {
     f << "sel?=" << sel[0];
     if (sel[1] != sel[0]) f << "<->" << sel[1] << ",";
@@ -967,7 +968,7 @@ bool HanMacWrdKParser::readZonec(shared_ptr<HanMacWrdKZone> zone)
           "Applications of Splay Trees to Data Compression" by Douglas W. Jones
           in Communications of the ACM, Aug. 1988, pages 996-1007.
 */
-shared_ptr<HanMacWrdKZone> HanMacWrdKParser::decodeZone(shared_ptr<HanMacWrdKZone> zone)
+std::shared_ptr<HanMacWrdKZone> HanMacWrdKParser::decodeZone(std::shared_ptr<HanMacWrdKZone> zone)
 {
   if (!zone || zone->fileBeginPos()+12 >= zone->fileEndPos()) {
     MWAW_DEBUG_MSG(("HanMacWrdKParser::decodeZone: called with an invalid zone\n"));
@@ -1094,11 +1095,11 @@ bool HanMacWrdKParser::checkHeader(MWAWHeader *header, bool strict)
   }
   input->seek(0,librevenge::RVNG_SEEK_SET);
   int head[3];
-  for (int i = 0; i < 3; i++)
-    head[i] = static_cast<int>(input->readULong(2));
+  for (int &i : head)
+    i = static_cast<int>(input->readULong(2));
   if (head[0] != 0x4859 || head[1] != 0x4c53 || head[2] != 0x0210)
     return false;
-  int val = static_cast<int>(input->readLong(1));
+  auto val = static_cast<int>(input->readLong(1));
   if (val==1) f << "hasPassword,";
   else if (val) {
     if (strict) return false;
@@ -1117,7 +1118,7 @@ bool HanMacWrdKParser::checkHeader(MWAWHeader *header, bool strict)
     MWAW_DEBUG_MSG(("HanMacWrdKParser::checkHeader: the header size seems short\n"));
   }
   f << "zonesBeg=" << std::hex << m_state->m_zonesListBegin << std::dec << ",";
-  long fLength = long(input->readULong(4));
+  auto fLength = long(input->readULong(4));
   if (fLength < m_state->m_zonesListBegin)
     return false;
   if (!input->checkPosition(fLength)) {
@@ -1125,7 +1126,7 @@ bool HanMacWrdKParser::checkHeader(MWAWHeader *header, bool strict)
     MWAW_DEBUG_MSG(("HanMacWrdKParser::checkHeader: file seems incomplete, try to continue\n"));
     f << "#len=" << std::hex << fLength << std::dec << ",";
   }
-  long tLength = long(input->readULong(4));
+  auto tLength = long(input->readULong(4));
   f << "textLength=" << tLength << ",";
   ascii().addPos(0);
   ascii().addNote(f.str().c_str());
@@ -1141,7 +1142,7 @@ bool HanMacWrdKParser::checkHeader(MWAWHeader *header, bool strict)
       input->seek(pos+fieldSizes[i], librevenge::RVNG_SEEK_SET);
       continue;
     }
-    int fSz = static_cast<int>(input->readULong(1));
+    auto fSz = static_cast<int>(input->readULong(1));
     if (fSz >= fieldSizes[i]) {
       if (strict)
         return false;
@@ -1181,13 +1182,33 @@ bool HanMacWrdKParser::checkHeader(MWAWHeader *header, bool strict)
 ////////////////////////////////////////////////////////////
 // HanMacWrdKZone
 ////////////////////////////////////////////////////////////
-HanMacWrdKZone::HanMacWrdKZone(MWAWInputStreamPtr input, libmwaw::DebugFile &asciiFile) : m_type(-1), m_id(-1), m_subId(-1), m_input(input), m_extra(""), m_parsed(false),
-  m_filePos(-1), m_endFilePos(-1), m_data(), m_asciiFile(&asciiFile), m_asciiFilePtr()
+HanMacWrdKZone::HanMacWrdKZone(MWAWInputStreamPtr const &input, libmwaw::DebugFile &asciiFile)
+  : m_type(-1)
+  , m_id(-1)
+  , m_subId(-1)
+  , m_input(input)
+  , m_extra("")
+  , m_parsed(false)
+  , m_filePos(-1)
+  , m_endFilePos(-1)
+  , m_data()
+  , m_asciiFile(&asciiFile)
+  , m_asciiFilePtr()
 {
 }
 
-HanMacWrdKZone::HanMacWrdKZone(shared_ptr<libmwaw::DebugFile> asciiFile) : m_type(-1), m_id(-1), m_subId(-1), m_input(), m_extra(""), m_parsed(false),
-  m_filePos(-1), m_endFilePos(-1), m_data(), m_asciiFile(asciiFile.get()), m_asciiFilePtr(asciiFile)
+HanMacWrdKZone::HanMacWrdKZone(std::shared_ptr<libmwaw::DebugFile> const &asciiFile)
+  : m_type(-1)
+  , m_id(-1)
+  , m_subId(-1)
+  , m_input()
+  , m_extra("")
+  , m_parsed(false)
+  , m_filePos(-1)
+  , m_endFilePos(-1)
+  , m_data()
+  , m_asciiFile(asciiFile.get())
+  , m_asciiFilePtr(asciiFile)
 {
 }
 
