@@ -64,12 +64,22 @@ namespace MWAWPresentationListenerInternal
 /** the global graphic state of MWAWPresentationListener */
 struct GraphicState {
   //! constructor
-  explicit GraphicState(std::vector<MWAWPageSpan> const &pageList) :
-    m_pageList(pageList), m_metaData(),
-    m_isDocumentStarted(false), m_isPageSpanOpened(false), m_isMasterPageSpanOpened(false), m_isAtLeastOnePageOpened(false),
-    m_isHeaderFooterStarted(false), m_pageSpan(), m_sentListMarkers(), m_subDocuments(), m_section()
+  explicit GraphicState(std::vector<MWAWPageSpan> const &pageList)
+    : m_pageList(pageList)
+    , m_metaData()
+    , m_isDocumentStarted(false)
+    , m_isPageSpanOpened(false)
+    , m_isMasterPageSpanOpened(false)
+    , m_isAtLeastOnePageOpened(false)
+    , m_isHeaderFooterStarted(false)
+    , m_pageSpan()
+    , m_sentListMarkers()
+    , m_subDocuments()
+    , m_section()
   {
   }
+  GraphicState &operator=(GraphicState const &)=default;
+  GraphicState &operator=(GraphicState &&)=default;
   //! destructor
   ~GraphicState()
   {
@@ -120,7 +130,7 @@ struct State {
   //! the paragraph
   MWAWParagraph m_paragraph;
   //! the list of list
-  shared_ptr<MWAWList> m_list;
+  std::shared_ptr<MWAWList> m_list;
 
   //! a flag to know if openFrame was called
   bool m_isFrameOpened;
@@ -158,27 +168,49 @@ struct State {
   libmwaw::SubDocumentType m_subDocumentType;
 
 private:
-  State(const State &);
-  State &operator=(const State &);
+  State(const State &) = delete;
+  State &operator=(const State &) = delete;
 };
 
-State::State() : m_origin(0,0),
-  m_textBuffer(""), m_font(20,12)/* default time 12 */, m_paragraph(), m_list(),
-  m_isFrameOpened(false), m_framePosition(), m_frameStyle(), m_isTextBoxOpened(false),
-  m_isGroupOpened(false), m_isLayerOpened(false),
-  m_isSpanOpened(false), m_isParagraphOpened(false), m_isListElementOpened(false),
-  m_firstParagraphInPageSpan(true), m_listOrderedLevels(),
-  m_isTableOpened(false), m_isTableRowOpened(false), m_isTableColumnOpened(false),
-  m_isTableCellOpened(false),
-  m_currentPage(0), m_numPagesRemainingInSpan(0), m_currentPageNumber(1),
-  m_inLink(false), m_inNote(false), m_inSubDocument(false), m_subDocumentType(libmwaw::DOC_NONE)
+State::State()
+  : m_origin(0,0)
+  , m_textBuffer("")
+  , m_font(20,12)/* default time 12 */
+  , m_paragraph()
+  , m_list()
+  , m_isFrameOpened(false)
+  , m_framePosition()
+  , m_frameStyle()
+  , m_isTextBoxOpened(false)
+  , m_isGroupOpened(false)
+  , m_isLayerOpened(false)
+  , m_isSpanOpened(false)
+  , m_isParagraphOpened(false)
+  , m_isListElementOpened(false)
+  , m_firstParagraphInPageSpan(true)
+  , m_listOrderedLevels()
+  , m_isTableOpened(false)
+  , m_isTableRowOpened(false)
+  , m_isTableColumnOpened(false)
+  , m_isTableCellOpened(false)
+  , m_currentPage(0)
+  , m_numPagesRemainingInSpan(0)
+  , m_currentPageNumber(1)
+  , m_inLink(false)
+  , m_inNote(false)
+  , m_inSubDocument(false)
+  , m_subDocumentType(libmwaw::DOC_NONE)
 {
 }
 }
 
-MWAWPresentationListener::MWAWPresentationListener(MWAWParserState &parserState, std::vector<MWAWPageSpan> const &pageList, librevenge::RVNGPresentationInterface *documentInterface) : MWAWListener(),
-  m_ds(new MWAWPresentationListenerInternal::GraphicState(pageList)), m_ps(new MWAWPresentationListenerInternal::State),
-  m_psStack(), m_parserState(parserState), m_documentInterface(documentInterface)
+MWAWPresentationListener::MWAWPresentationListener(MWAWParserState &parserState, std::vector<MWAWPageSpan> const &pageList, librevenge::RVNGPresentationInterface *documentInterface)
+  : MWAWListener()
+  , m_ds(new MWAWPresentationListenerInternal::GraphicState(pageList))
+  , m_ps(new MWAWPresentationListenerInternal::State)
+  , m_psStack()
+  , m_parserState(parserState)
+  , m_documentInterface(documentInterface)
 {
 }
 
@@ -399,7 +431,7 @@ void MWAWPresentationListener::openLink(MWAWLink const &link)
   m_documentInterface->openLink(propList);
   _pushParsingState();
   m_ps->m_inLink=true;
-// we do not want any close open paragraph in a link
+  // we do not want any close open paragraph in a link
   m_ps->m_isParagraphOpened=true;
 }
 
@@ -522,7 +554,7 @@ void MWAWPresentationListener::_openPageSpan(bool sendHeaderFooters)
   }
   m_ds->m_isAtLeastOnePageOpened=true;
   unsigned actPage = 0;
-  std::vector<MWAWPageSpan>::iterator it = m_ds->m_pageList.begin();
+  auto it = m_ds->m_pageList.begin();
   m_ps->m_currentPage++;
   while (true) {
     actPage+=static_cast<unsigned>(it->getPageSpan());
@@ -691,7 +723,7 @@ void MWAWPresentationListener::_closeListElement()
 
 int MWAWPresentationListener::_getListId() const
 {
-  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
+  auto newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
   if (newLevel == 0) return -1;
   int newListId = m_ps->m_paragraph.m_listId.get();
   if (newListId > 0) return newListId;
@@ -700,8 +732,7 @@ int MWAWPresentationListener::_getListId() const
     MWAW_DEBUG_MSG(("MWAWPresentationListener::_getListId: the list id is not set, try to find a new one\n"));
     first = false;
   }
-  shared_ptr<MWAWList> list=m_parserState.m_listManager->getNewList
-                            (m_ps->m_list, int(newLevel), *m_ps->m_paragraph.m_listLevel);
+  auto list=m_parserState.m_listManager->getNewList(m_ps->m_list, int(newLevel), *m_ps->m_paragraph.m_listLevel);
   if (!list) return -1;
   return list->getId();
 }
@@ -716,7 +747,7 @@ void MWAWPresentationListener::_changeList()
     _closeParagraph();
 
   size_t actualLevel = m_ps->m_listOrderedLevels.size();
-  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
+  auto newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
   if (newLevel>100) {
     MWAW_DEBUG_MSG(("MWAWPresentationListener::_changeList: find level=%d, set it to 100\n", static_cast<int>(newLevel)));
     newLevel=100;
@@ -733,7 +764,7 @@ void MWAWPresentationListener::_changeList()
   }
 
   if (newLevel) {
-    shared_ptr<MWAWList> theList;
+    std::shared_ptr<MWAWList> theList;
 
     theList=m_parserState.m_listManager->getList(newListId);
     if (!theList) {
@@ -849,7 +880,7 @@ bool MWAWPresentationListener::isHeaderFooterOpened() const
   return m_ds->m_isHeaderFooterStarted;
 }
 
-bool MWAWPresentationListener::insertHeader(MWAWSubDocumentPtr subDocument, librevenge::RVNGPropertyList const &extras)
+bool MWAWPresentationListener::insertHeader(MWAWSubDocumentPtr const &subDocument, librevenge::RVNGPropertyList const &extras)
 {
   if (m_ds->m_isHeaderFooterStarted) {
     MWAW_DEBUG_MSG(("MWAWPresentationListener::insertHeader: Oops a header/footer is already opened\n"));
@@ -870,7 +901,7 @@ bool MWAWPresentationListener::insertHeader(MWAWSubDocumentPtr subDocument, libr
   return true;
 }
 
-bool MWAWPresentationListener::insertFooter(MWAWSubDocumentPtr subDocument, librevenge::RVNGPropertyList const &extras)
+bool MWAWPresentationListener::insertFooter(MWAWSubDocumentPtr const &subDocument, librevenge::RVNGPropertyList const &extras)
 {
   if (m_ds->m_isHeaderFooterStarted) {
     MWAW_DEBUG_MSG(("MWAWPresentationListener::insertFooter: Oops a header/footer is already opened\n"));
@@ -1056,7 +1087,7 @@ void MWAWPresentationListener::insertPicture(MWAWPosition const &pos, MWAWEmbedd
 }
 
 void MWAWPresentationListener::insertTextBox
-(MWAWPosition const &pos, MWAWSubDocumentPtr subDocument, MWAWGraphicStyle const &style)
+(MWAWPosition const &pos, MWAWSubDocumentPtr const &subDocument, MWAWGraphicStyle const &style)
 {
   if (!m_ds->m_isDocumentStarted) {
     MWAW_DEBUG_MSG(("MWAWPresentationListener::insertTextBox: the document is not started\n"));
@@ -1116,7 +1147,7 @@ void MWAWPresentationListener::insertSlideNote(MWAWPosition const &pos, MWAWSubD
   closeFrame();
 }
 
-void MWAWPresentationListener::insertGroup(MWAWBox2f const &bdbox, MWAWSubDocumentPtr subDocument)
+void MWAWPresentationListener::insertGroup(MWAWBox2f const &bdbox, MWAWSubDocumentPtr const &subDocument)
 {
   if (!m_ds->m_isDocumentStarted || m_ps->isInTextZone()) {
     MWAW_DEBUG_MSG(("MWAWPresentationListener::insertGroup: can not insert a group\n"));
@@ -1143,7 +1174,7 @@ void MWAWPresentationListener::insertTable
   _startSubDocument();
   m_ps->m_subDocumentType = libmwaw::DOC_TABLE;
 
-  shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWPresentationListener>());
+  std::shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWPresentationListener>());
   try {
     table.sendTable(listen);
   }
@@ -1573,7 +1604,7 @@ void MWAWPresentationListener::_handleFrameParameters(librevenge::RVNGPropertyLi
 ///////////////////
 // subdocument
 ///////////////////
-void MWAWPresentationListener::handleSubDocument(MWAWVec2f const &orig, MWAWSubDocumentPtr subDocument, libmwaw::SubDocumentType subDocumentType)
+void MWAWPresentationListener::handleSubDocument(MWAWVec2f const &orig, MWAWSubDocumentPtr const &subDocument, libmwaw::SubDocumentType subDocumentType)
 {
   if (!m_ds->m_isDocumentStarted) {
     MWAW_DEBUG_MSG(("MWAWPresentationListener::handleSubDocument: the graphic is not started\n"));
@@ -1598,10 +1629,11 @@ void MWAWPresentationListener::handleSubDocument(MWAWVec2f const &orig, MWAWSubD
     m_ps->m_inNote=true;
   // Check whether the document is calling itself
   bool sendDoc = true;
-  for (size_t i = 0; i < m_ds->m_subDocuments.size(); i++) {
+  for (auto doc : m_ds->m_subDocuments) {
     if (!subDocument)
       break;
-    if (subDocument == m_ds->m_subDocuments[i]) {
+    if (!doc) continue;
+    if (*subDocument == *doc) {
       MWAW_DEBUG_MSG(("MWAWPresentationListener::handleSubDocument: recursif call, stop...\n"));
       sendDoc = false;
       break;
@@ -1610,7 +1642,7 @@ void MWAWPresentationListener::handleSubDocument(MWAWVec2f const &orig, MWAWSubD
   if (sendDoc) {
     if (subDocument) {
       m_ds->m_subDocuments.push_back(subDocument);
-      shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWListener>());
+      std::shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWListener>());
       try {
         subDocument->parse(listen, subDocumentType);
       }
@@ -1660,9 +1692,9 @@ void MWAWPresentationListener::_endSubDocument()
 ///////////////////
 
 // ---------- state stack ------------------
-shared_ptr<MWAWPresentationListenerInternal::State> MWAWPresentationListener::_pushParsingState()
+std::shared_ptr<MWAWPresentationListenerInternal::State> MWAWPresentationListener::_pushParsingState()
 {
-  shared_ptr<MWAWPresentationListenerInternal::State> actual = m_ps;
+  auto actual = m_ps;
   m_psStack.push_back(actual);
   m_ps.reset(new MWAWPresentationListenerInternal::State);
   m_ps->m_origin=actual->m_origin;
