@@ -62,7 +62,13 @@ namespace MacDocParserInternal
 //! Internal: the index data of a MacDocParser
 struct Index {
   //! constructor
-  Index() : m_entry(), m_level(0), m_numChild(0), m_page(0), m_box(), m_extra("")
+  Index()
+    : m_entry()
+    , m_level(0)
+    , m_numChild(0)
+    , m_page(0)
+    , m_box()
+    , m_extra("")
   {
   }
   //! operator<<
@@ -93,7 +99,12 @@ struct Index {
 //! Internal: the state of a MacDocParser
 struct State {
   //! constructor
-  State() : m_idPictureMap(), m_indexList(), m_idFontMap(), m_actPage(0), m_numPages(0)
+  State()
+    : m_idPictureMap()
+    , m_indexList()
+    , m_idFontMap()
+    , m_actPage(0)
+    , m_numPages(0)
   {
   }
   //! the picture page map
@@ -110,8 +121,9 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MacDocParser::MacDocParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state()
+MacDocParser::MacDocParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
 {
   init();
 }
@@ -161,10 +173,10 @@ void MacDocParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void MacDocParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !getRSRCParser() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !getRSRCParser() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -196,7 +208,7 @@ void MacDocParser::createDocument(librevenge::RVNGTextInterface *documentInterfa
   m_state->m_actPage = 0;
 
   // create the page list
-  int numPages = int(m_state->m_idPictureMap.size());
+  auto numPages = int(m_state->m_idPictureMap.size());
   if (!m_state->m_indexList.empty())
     numPages++;
   MWAWPageSpan ps(getPageSpan());
@@ -217,11 +229,10 @@ void MacDocParser::createDocument(librevenge::RVNGTextInterface *documentInterfa
 bool MacDocParser::createZones()
 {
   MWAWRSRCParserPtr rsrcParser = getRSRCParser();
-  std::multimap<std::string, MWAWEntry> &entryMap = rsrcParser->getEntriesMap();
-  std::multimap<std::string, MWAWEntry>::iterator it;
+  auto &entryMap = rsrcParser->getEntriesMap();
 
   // the index font zone: 1001, ...
-  it = entryMap.lower_bound("MDLv");
+  auto it = entryMap.lower_bound("MDLv");
   while (it != entryMap.end()) {
     if (it->first != "MDLv")
       break;
@@ -263,7 +274,7 @@ bool MacDocParser::createZones()
       if (!pictInput)
         continue;
       MWAWBox2f box;
-      MWAWPict::ReadResult res = MWAWPictData::check(pictInput,(int) data.size(), box);
+      auto res = MWAWPictData::check(pictInput,static_cast<int>(data.size()), box);
       if (res != MWAWPict::MWAW_R_BAD && box.size()[0]>0 && box.size()[1]>0) {
         pageSizeSet=true;
         getPageSpan().setFormWidth(double(box.size()[0])/72.);
@@ -292,7 +303,7 @@ bool MacDocParser::createZones()
 
   // get rid of the default application resource
   libmwaw::DebugFile &ascFile = rsrcAscii();
-  static char const *(appliRsrc[])= {
+  static char const *appliRsrc[]= {
     "ALRT","BNDL","CNTL","CURS","CDEF", "CODE","DLOG","DLGX","DITL","FREF",
     "ICON","ICN#","MENU","MBAR","MDEF", "SIZE","TMPL","WIND",
     "acur","cicn","crsr","dctb","icl4", "icl8","ics4","ics8","ics#","ictb",
@@ -327,9 +338,8 @@ bool MacDocParser::sendContents()
   if (sendIndex())
     newPage(++actPage);
   listener->setParagraph(MWAWParagraph());
-  std::map<int,MWAWEntry>::const_iterator it=m_state->m_idPictureMap.begin();
-  for (; it!=m_state->m_idPictureMap.end(); ++it) {
-    sendPicture(it->second);
+  for (auto &it : m_state->m_idPictureMap) {
+    sendPicture(it.second);
     newPage(++actPage);
   }
   return true;
@@ -354,7 +364,7 @@ bool MacDocParser::readFont(MWAWEntry const &entry)
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
   libmwaw::DebugFile &ascFile = rsrcAscii();
   libmwaw::DebugStream f;
-  int fSz=(int) input->readULong(1);
+  auto fSz=static_cast<int>(input->readULong(1));
   if (fSz<0 || 1+long(fSz)+1-(fSz%2)+10>entry.length()) {
     f << "Entries(Font):###fSz=" << fSz;
     ascFile.addPos(entry.begin()-4);
@@ -364,12 +374,12 @@ bool MacDocParser::readFont(MWAWEntry const &entry)
   MWAWFont font;
   std::string name("");
   for (int i=0; i<fSz; i++)
-    name+=(char) input->readLong(1);
+    name+=char(input->readLong(1));
   font.setId(getParserState()->m_fontConverter->getId(name));
   if ((fSz%2)==0)
     input->seek(1, librevenge::RVNG_SEEK_CUR);
-  font.setSize((float) input->readULong(2));
-  int flag = (int) input->readULong(2);
+  font.setSize(float(input->readULong(2)));
+  auto flag = static_cast<int>(input->readULong(2));
   uint32_t flags=0;
   if (flag&0x1) flags |= MWAWFont::boldBit;
   if (flag&0x2) flags |= MWAWFont::italicBit;
@@ -381,8 +391,7 @@ bool MacDocParser::readFont(MWAWEntry const &entry)
   if (flag&0x80) f << "#flag0[0x80],";
   font.setFlags(flags);
   unsigned char col[3];
-  for (int c=0; c < 3; ++c)
-    col[c]=(unsigned char)(input->readULong(2)>>8);
+  for (auto &c : col) c=static_cast<unsigned char>(input->readULong(2)>>8);
   font.setColor(MWAWColor(col[0],col[1],col[2]));
   font.m_extra = f.str();
   f.str("");
@@ -422,22 +431,21 @@ bool MacDocParser::readIndex(MWAWEntry const &entry)
 
     f.str("");
     MacDocParserInternal::Index index;
-    int val=(int) input->readLong(2);
+    auto val=static_cast<int>(input->readLong(2));
     if (val) f << "#f0=" << val << ",";
-    index.m_page=(int) input->readLong(2);
+    index.m_page=static_cast<int>(input->readLong(2));
     if (index.m_page<=0) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       break;
     }
     int dim[4];
-    for (int i=0; i<4; ++i)
-      dim[i]=(int) input->readLong(2);
+    for (auto &d : dim) d=static_cast<int>(input->readLong(2));
     index.m_box=MWAWBox2i(MWAWVec2i(dim[1],dim[0]),MWAWVec2i(dim[3],dim[2]));
-    val=(int) input->readLong(2);
+    val=static_cast<int>(input->readLong(2));
     if (val) f << "#f1=" << val << ",";
-    index.m_numChild=(int) input->readLong(2);
+    index.m_numChild=static_cast<int>(input->readLong(2));
     for (int i=0; i<2; ++i) {
-      val=(int) input->readLong(2);
+      val=static_cast<int>(input->readLong(2));
       if (val) f << "#f" << i+2 << "=" << val << ",";
     }
     index.m_extra=f.str();
@@ -449,7 +457,7 @@ bool MacDocParser::readIndex(MWAWEntry const &entry)
     while (!input->isEnd()) {
       if (input->tell()>=entry.end())
         break;
-      char c=(char) input->readLong(1);
+      auto c=char(input->readLong(1));
       if (c==0) {
         ok = true;
         break;
@@ -480,12 +488,12 @@ bool MacDocParser::readIndex(MWAWEntry const &entry)
 
 int MacDocParser::updateIndex(int actIndex, int actLevel)
 {
-  int numIndex=(int) m_state->m_indexList.size();
+  auto numIndex=static_cast<int>(m_state->m_indexList.size());
   if (actIndex < 0 || actIndex >= numIndex) {
     MWAW_DEBUG_MSG(("MacDocParser::updateIndex: the actual index seems bad\n"));
     return -1;
   }
-  MacDocParserInternal::Index &index =  m_state->m_indexList[size_t(actIndex++)];
+  auto &index =  m_state->m_indexList[size_t(actIndex++)];
   index.m_level=actLevel;
   for (int c=0; c < index.m_numChild; ++c) {
     actIndex=updateIndex(actIndex, actLevel+1);
@@ -505,15 +513,15 @@ bool MacDocParser::sendIndex()
   if (m_state->m_indexList.empty())
     return false;
   int id=0;
-  size_t numIndex=(size_t) m_state->m_indexList.size();
+  auto numIndex=size_t(m_state->m_indexList.size());
   do
     id=updateIndex(id,1);
-  while (id>0 && id < (int) numIndex);
+  while (id>0 && id < static_cast<int>(numIndex));
   listener->setFont(MWAWFont(3,12,MWAWFont::boldBit));
   MWAWParagraph para;
   para.m_justify = MWAWParagraph::JustificationCenter;
   listener->setParagraph(para);
-  listener->insertUnicodeString("Index");
+  listener->insertUnicodeString(librevenge::RVNGString("Index"));
   listener->insertEOL();
   listener->insertEOL();
 
@@ -525,8 +533,13 @@ bool MacDocParser::sendIndex()
   tab.m_leaderCharacter='.';
   tab.m_position = w-0.3;
   para.m_tabs->push_back(tab);
-  for (size_t i=0; i < numIndex; ++i) {
-    MacDocParserInternal::Index const &index =  m_state->m_indexList[i];
+#ifdef DEBUG
+  int n=0;
+#endif
+  for (auto const &index : m_state->m_indexList) {
+#ifdef DEBUG
+    ++n;
+#endif
     if (!index.m_entry.valid() || index.m_level<=0)
       continue;
     para.m_margins[1]=0.5*double(index.m_level);
@@ -534,12 +547,12 @@ bool MacDocParser::sendIndex()
     if (m_state->m_idFontMap.find(index.m_level)!=m_state->m_idFontMap.end())
       listener->setFont(m_state->m_idFontMap.find(index.m_level)->second);
     else {
-      MWAW_DEBUG_MSG(("MacDocParser::sendIndex: can not find font for index %d\n", int(i)));
+      MWAW_DEBUG_MSG(("MacDocParser::sendIndex: can not find font for index %d\n", int(n-1)));
       listener->setFont(MWAWFont());
     }
     input->seek(index.m_entry.begin(), librevenge::RVNG_SEEK_SET);
     for (long c=0; c < index.m_entry.length(); ++c) {
-      unsigned char ch=(unsigned char)input->readULong(1);
+      auto ch=static_cast<unsigned char>(input->readULong(1));
       if (ch==9)
         listener->insertCharacter(' ');
       else
@@ -550,7 +563,7 @@ bool MacDocParser::sendIndex()
       s << index.m_page;
       listener->setFont(MWAWFont());
       listener->insertTab();
-      listener->insertUnicodeString(s.str().c_str());
+      listener->insertUnicodeString(librevenge::RVNGString(s.str().c_str()));
     }
     listener->insertEOL();
   }
@@ -569,7 +582,7 @@ bool MacDocParser::sendPicture(MWAWEntry const &entry)
     return false;
 
   entry.setParsed(true);
-  int dataSz=int(data.size());
+  auto dataSz=int(data.size());
   if (!dataSz)
     return false;
   MWAWInputStreamPtr pictInput=MWAWInputStream::get(data, false);
@@ -578,13 +591,13 @@ bool MacDocParser::sendPicture(MWAWEntry const &entry)
     return false;
   }
   MWAWBox2f box;
-  MWAWPict::ReadResult res = MWAWPictData::check(pictInput, dataSz,box);
+  auto res = MWAWPictData::check(pictInput, dataSz,box);
   if (res == MWAWPict::MWAW_R_BAD) {
     MWAW_DEBUG_MSG(("MacDocParser::sendPicture: can not find the picture\n"));
     return false;
   }
   pictInput->seek(0,librevenge::RVNG_SEEK_SET);
-  shared_ptr<MWAWPict> thePict(MWAWPictData::get(pictInput, dataSz));
+  std::shared_ptr<MWAWPict> thePict(MWAWPictData::get(pictInput, dataSz));
   MWAWPosition pictPos=MWAWPosition(MWAWVec2f(0,0),box.size(), librevenge::RVNG_POINT);
   pictPos.setRelativePosition(MWAWPosition::Char);
   if (thePict) {
@@ -683,7 +696,7 @@ bool MacDocParser::checkHeader(MWAWHeader *header, bool strict)
   }
   if (strict) {
     // check if at least one picture zone exists
-    std::multimap<std::string, MWAWEntry> &entryMap = getRSRCParser()->getEntriesMap();
+    auto &entryMap = getRSRCParser()->getEntriesMap();
     if (entryMap.find("MDpg") == entryMap.end())
       return false;
   }
