@@ -58,7 +58,11 @@ namespace MacDraftParserInternal
 //! low level: bitmap file position in a MacDraft file
 struct BitmapFileData {
   //! constructor
-  BitmapFileData() : m_id(0), m_rowSize(0), m_dimension(), m_entry()
+  BitmapFileData()
+    : m_id(0)
+    , m_rowSize(0)
+    , m_dimension()
+    , m_entry()
   {
   }
   //! check is the entry is coherent
@@ -84,9 +88,24 @@ struct Shape {
   enum Type { Basic, Bitmap, Group, Label, Text, Unknown };
 
   //! constructor
-  Shape() : m_type(Unknown), m_box(), m_origin(), m_style(), m_patternId(-1), m_shape(), m_isLine(false), m_id(-1), m_nextId(-1),
-    m_font(), m_paragraph(), m_textEntry(), m_labelWidth(0), m_childList(),
-    m_bitmapIdList(), m_bitmapDimensionList(), m_isSent(false)
+  Shape()
+    : m_type(Unknown)
+    , m_box()
+    , m_origin()
+    , m_style()
+    , m_patternId(-1)
+    , m_shape()
+    , m_isLine(false)
+    , m_id(-1)
+    , m_nextId(-1)
+    , m_font()
+    , m_paragraph()
+    , m_textEntry()
+    , m_labelWidth(0)
+    , m_childList()
+    , m_bitmapIdList()
+    , m_bitmapDimensionList()
+    , m_isSent(false)
   {
   }
 
@@ -192,7 +211,11 @@ struct Shape {
 //! Internal: the state of a MacDraftParser
 struct State {
   //! constructor
-  State() : m_version(0), m_patternList(), m_shapeList(), m_idToBitmapMap()
+  State()
+    : m_version(0)
+    , m_patternList()
+    , m_shapeList()
+    , m_idToBitmapMap()
   {
   }
   //! returns a pattern if posible
@@ -223,7 +246,7 @@ void State::initPatterns()
 {
   if (!m_patternList.empty()) return;
   for (int i=0; i<64; ++i) {
-    static uint16_t const(patterns[]) = {
+    static uint16_t const patterns[] = {
       0x0, 0x0, 0x0, 0x0, 0x40, 0x400, 0x10, 0x100, 0x8040, 0x2010, 0x804, 0x201, 0x102, 0x408, 0x1020, 0x4080,
       0x0, 0x0, 0x0, 0x0, 0x842, 0x90, 0x440, 0x1001, 0xe070, 0x381c, 0xe07, 0x83c1, 0x8307, 0xe1c, 0x3870, 0xe0c1,
       0x8000, 0x0, 0x800, 0x0, 0x42a, 0x4025, 0x251, 0x2442, 0x4422, 0x88, 0x4422, 0x88, 0x1122, 0x4400, 0x1122, 0x4400,
@@ -257,38 +280,37 @@ void State::initPatterns()
 }
 ////////////////////////////////////////
 //! Internal: the subdocument of a MacDraftParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(MacDraftParser &pars, MWAWInputStreamPtr input, int zoneId) : MWAWSubDocument(&pars, input, MWAWEntry()), m_id(zoneId) {}
+  SubDocument(MacDraftParser &pars, MWAWInputStreamPtr const &input, int zoneId)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+    , m_id(zoneId)
+  {
+  }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     if (m_id != sDoc->m_id) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   //! the subdocument id
   int m_id;
 private:
-  SubDocument(SubDocument const &orig);
-  SubDocument &operator=(SubDocument const &orig);
+  SubDocument(SubDocument const &orig) = delete;
+  SubDocument &operator=(SubDocument const &orig) = delete;
 };
 
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
@@ -297,7 +319,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
     MWAW_DEBUG_MSG(("MacDraftParserInternal::SubDocument::parse: no listener\n"));
     return;
   }
-  MacDraftParser *parser=dynamic_cast<MacDraftParser *>(m_parser);
+  auto *parser=dynamic_cast<MacDraftParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("MacDraftParserInternal::SubDocument::parse: no parser\n"));
     return;
@@ -307,14 +329,14 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
 }
 
-
 }
 
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MacDraftParser::MacDraftParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWGraphicParser(input, rsrcParser, header), m_state()
+MacDraftParser::MacDraftParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWGraphicParser(input, rsrcParser, header)
+  , m_state()
 {
   init();
 }
@@ -338,16 +360,17 @@ void MacDraftParser::init()
 ////////////////////////////////////////////////////////////
 void MacDraftParser::parse(librevenge::RVNGDrawingInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
+      // reimplement me, ie. we may loose some shape if the chain is breaked
       for (size_t i=0; i<m_state->m_shapeList.size(); ++i) {
         MacDraftParserInternal::Shape const &shape=m_state->m_shapeList[i];
         if (shape.m_isSent) continue;
@@ -402,7 +425,7 @@ bool MacDraftParser::createZones()
   while (readPattern()) {
   }
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   if (fSz==0) {
     ascii().addPos(pos);
     ascii().addNote("Patterns[end]:");
@@ -542,7 +565,7 @@ bool MacDraftParser::readZone()
   if (input->isEnd())
     return false;
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   if (fSz==0) {
     ascii().addPos(pos);
     ascii().addNote("_");
@@ -573,7 +596,7 @@ bool MacDraftParser::readObject()
   if (input->isEnd())
     return false;
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   if (fSz==0x1a) {
     input->seek(pos,librevenge::RVNG_SEEK_SET);
     return readLabel();
@@ -669,7 +692,7 @@ bool MacDraftParser::readObject()
     f << "rot=" << val << ",";
   }
   float dim[4];
-  for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+  for (auto &d : dim) d=float(input->readLong(2))/8.f;
   shape.m_box=MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
   f << "dim=" << shape.m_box << ",";
   for (int i=0; i<2; ++i) dim[i]=float(input->readLong(2))/8.f;
@@ -683,7 +706,7 @@ bool MacDraftParser::readObject()
     shape.m_type=MacDraftParserInternal::Shape::Basic;
     val=static_cast<int>(input->readULong(4));
     if (val) f << "id?=" << std::hex << val << std::dec << ",";
-    for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+    for (auto &d : dim) d=float(input->readLong(2))/8.f;
     MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
     f << "dim1=" << box << ",";
     if (fSz==0x28) {
@@ -718,9 +741,10 @@ bool MacDraftParser::readObject()
     else if (fSz==0x38)
       f << "pie,";
     else {
+      // must not appear
       static bool first=true;
       if (first) {
-        MWAW_DEBUG_MSG(("MacDraftParser::readObject: find some bitmap\n"));
+        MWAW_DEBUG_MSG(("MacDraftParser::readObject: find unexpected data\n"));
         first=false;
       }
       f << "Bitmap###,";
@@ -732,7 +756,7 @@ bool MacDraftParser::readObject()
     }
     else if (fSz==0x38) {
       int fileAngle[2];
-      for (int i=0; i<2; ++i) fileAngle[i]=static_cast<int>(input->readLong(2));
+      for (auto &angle : fileAngle) angle=static_cast<int>(input->readLong(2));
       f << "angle=" << fileAngle[0] << "x" << fileAngle[0]+fileAngle[1] << ",";
       if (fileAngle[1]<0) {
         fileAngle[0]+=fileAngle[1];
@@ -866,7 +890,7 @@ bool MacDraftParser::readObject()
     val=static_cast<int>(input->readLong(2)); // always 2
     if (val != 1)
       f << "f2=" << val << ",";
-    for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+    for (auto &d : dim) d=float(input->readLong(2))/8.f;
     MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
     f << "line=" << box << ",";
     shape.m_type=MacDraftParserInternal::Shape::Basic;
@@ -885,7 +909,7 @@ bool MacDraftParser::readObject()
         if (val)
           f << "f" << i << "=" << val << ",";
       }
-      for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+      for (auto &d : dim) d=float(input->readLong(2))/8.f;
       MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
       shape.m_box=box;
       f << "box=" << box << ",";
@@ -972,7 +996,7 @@ bool MacDraftParser::readObject()
       val=static_cast<int>(input->readLong(2));
       if (val!=1) // find 1 or 3
         f << "f5=" << val << ",";
-      int N=static_cast<int>(input->readULong(2));
+      auto N=static_cast<int>(input->readULong(2));
       if (input->tell()+4+N>endPos) {
         MWAW_DEBUG_MSG(("MacDraftParser::readObject: can not read the number of char \n"));
         f << "##N=" << N << ",";
@@ -993,8 +1017,8 @@ bool MacDraftParser::readObject()
     }
     val=static_cast<int>(input->readULong(4));
     if (val) f << "pat[id]=" << std::hex << val << ",";
-    for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
-    int N=static_cast<int>(input->readULong(2));
+    for (auto &d: dim) d=float(input->readLong(2))/8.f;
+    auto N=static_cast<int>(input->readULong(2));
     if (N*4+46==fSz) {
       f << "poly, box=" << MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2])) << ",";
       shape.m_type=MacDraftParserInternal::Shape::Basic;
@@ -1003,8 +1027,9 @@ bool MacDraftParser::readObject()
       MWAWBox2f box;
       f << "pts=[";
       for (int i=0; i<N; ++i) {
-        for (int j=0; j<2; ++j) dim[j]=float(input->readLong(2))/8.f;
-        MWAWVec2f point=MWAWVec2f(dim[1],dim[0]);
+        float coord[2];
+        for (auto &c : coord) c=float(input->readLong(2))/8.f;
+        MWAWVec2f point=MWAWVec2f(coord[1],coord[0]);
         vertices.push_back(point);
         if (i==0)
           box=MWAWBox2f(point, point);
@@ -1044,7 +1069,7 @@ bool MacDraftParser::readBitmapData()
   if (input->isEnd())
     return false;
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   long endPos=pos+2+fSz;
   if (fSz<28 || !input->checkPosition(endPos)) {
     input->seek(pos,librevenge::RVNG_SEEK_SET);
@@ -1053,7 +1078,7 @@ bool MacDraftParser::readBitmapData()
   MacDraftParserInternal::BitmapFileData data;
   libmwaw::DebugStream f;
   f << "Entries(BitmapData):";
-  long val=long(input->readULong(4));
+  auto val=long(input->readULong(4));
   if (val)
     f << "id[next]=" << std::hex << val << std::dec << ",";
   val=long(input->readULong(2));
@@ -1068,7 +1093,7 @@ bool MacDraftParser::readBitmapData()
   data.m_rowSize=static_cast<int>(input->readULong(2)); // 2|4|72 : number of bytes by row
   if (data.m_rowSize) f << "row[size]=" << data.m_rowSize << ",";
   int dim[4];
-  for (int i=0; i<4; ++i) dim[i]=static_cast<int>(input->readLong(2));
+  for (auto &d : dim) d=static_cast<int>(input->readLong(2));
   data.m_dimension=MWAWBox2i(MWAWVec2i(dim[1],dim[0]),MWAWVec2i(dim[3],dim[2]));
   f << "dim=" << data.m_dimension << ",";
   data.m_entry.setBegin(input->tell());
@@ -1101,7 +1126,7 @@ bool MacDraftParser::readBitmapDefinition(MacDraftParserInternal::Shape &bitmap)
   if (input->isEnd())
     return false;
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   long endPos=pos+2+fSz;
   if (fSz!=0x3e || !input->checkPosition(endPos)) {
     input->seek(pos,librevenge::RVNG_SEEK_SET);
@@ -1133,25 +1158,27 @@ bool MacDraftParser::readBitmapDefinition(MacDraftParserInternal::Shape &bitmap)
   if (val)
     f << "rot=" << float(val) << ",";
   float dim[4];
-  for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+  for (auto &d : dim) d=float(input->readLong(2))/8.f;
   f << "dim=" << MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2])) << ",";
-  for (int i=0; i<2; ++i) dim[i]=float(input->readLong(2))/8.f;
-  f << "orig=" << MWAWVec2f(dim[1],dim[0]) << ",";
+  float coord[2];
+  for (auto &c : coord) c=float(input->readLong(2))/8.f;
+  f << "orig=" << MWAWVec2f(coord[1],coord[0]) << ",";
 
   val=static_cast<int>(input->readULong(4));
   if (val) f << "id?=" << std::hex << val << std::dec << ",";
-  for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+  for (auto &d : dim) d=float(input->readLong(2))/8.f;
   f << "dim1=" << MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2])) << ",";
   unsigned long id=input->readULong(4);
   bitmap.m_bitmapIdList.push_back(id);
   f << "id[data]=" << std::hex << id << std::dec << ",";
   val=static_cast<int>(input->readLong(2)); // 0|1
   if (val) f << "g0=" << val << ",";
-  for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2));
-  MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
+  int iDim[4];
+  for (auto &d : iDim) d=int(input->readLong(2));
+  MWAWBox2i box(MWAWVec2i(iDim[1],iDim[0]), MWAWVec2i(iDim[3],iDim[2]));
   bitmap.m_bitmapDimensionList.push_back(box);
   f << "dim2=" << box << ",";
-  for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2));
+  for (auto &d : dim) d=float(input->readLong(2));
   f << "dim3=" << MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2])) << ",";
 
   if (input->tell()!=endPos)
@@ -1171,7 +1198,7 @@ bool MacDraftParser::readPattern()
   if (input->isEnd())
     return false;
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   long endPos=pos+2+fSz;
   if (fSz!=0x1e || !input->checkPosition(endPos)) {
     input->seek(pos,librevenge::RVNG_SEEK_SET);
@@ -1179,9 +1206,9 @@ bool MacDraftParser::readPattern()
   }
   libmwaw::DebugStream f;
   f << "Entries(Pattern):";
-  long val=long(input->readULong(4));
+  auto val=long(input->readULong(4));
   if (val) f << "id=" << std::hex << val << std::dec << ",";
-  int id=static_cast<int>(input->readULong(2));
+  auto id=static_cast<int>(input->readULong(2));
   if (id==0xf0)
     f << "default,";
   else if (id<64)
@@ -1202,9 +1229,9 @@ bool MacDraftParser::readPattern()
   pat.m_colors[0]=MWAWColor::white();
   pat.m_colors[1]=MWAWColor::black();
 
-  for (size_t i=0; i<8; ++i) pat.m_data[i]=uint8_t(input->readULong(1));
+  for (auto &data : pat.m_data) data=uint8_t(input->readULong(1));
   f << "orig=" << pat << ",";
-  for (size_t i=0; i<8; ++i) pat.m_data[i]=uint8_t(input->readULong(1));
+  for (auto &data : pat.m_data) data=uint8_t(input->readULong(1));
   f << "final=" << pat << ",";
   if (id>=0 && id<64) {
     m_state->initPatterns();
@@ -1225,7 +1252,7 @@ bool MacDraftParser::readLabel()
   if (input->isEnd())
     return false;
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   long endPos=pos+2+fSz;
   if (fSz!=0x1a || !input->checkPosition(endPos)) {
     input->seek(pos,librevenge::RVNG_SEEK_SET);
@@ -1317,7 +1344,7 @@ bool MacDraftParser::readLabel()
   if (flag&0xFFFF) f << "fl1[l]=" << std::hex << (flag&0xFFFF) << std::dec << ",";
 
   float dim[4];
-  for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2))/8.f;
+  for (auto &d : dim) d=float(input->readLong(2))/8.f;
   shape.m_box=MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
   f << shape.m_box << ",";
   val=static_cast<int>(input->readULong(2));
@@ -1347,7 +1374,7 @@ bool MacDraftParser::checkHeader(MWAWHeader *header, bool strict)
       input->readULong(2)!=0x262 || input->readULong(2)!=0x262)
     return false;
   int const vers=1;
-  int val=static_cast<int>(input->readULong(2));
+  auto val=static_cast<int>(input->readULong(2));
   if (val)
     f << "f0=" << val << ",";
   f << "id=" << std::hex << input->readULong(4) << std::dec << ",";
@@ -1371,7 +1398,7 @@ bool MacDraftParser::checkHeader(MWAWHeader *header, bool strict)
   val=static_cast<int>(input->readLong(2)); // 0|1
   if (val)
     f << "f2=" << val << ",";
-  int sSz=static_cast<int>(input->readULong(1));
+  auto sSz=static_cast<int>(input->readULong(1));
   if (sSz>31) {
     if (strict)
       return false;
@@ -1427,9 +1454,9 @@ bool MacDraftParser::readDocHeader()
   int val;
   for (int i=0; i<16; ++i) {
     val=static_cast<int>(input->readULong(2));
-    static int const(expected[])= {0,1,0,0,0xdfff,0xffff,0,0, 0xeed7, 0xffff, 0, 0,
-                                   0x9dd5, 0xbfff,0x4088,0x8000
-                                  };
+    static int const expected[]= {0,1,0,0,0xdfff,0xffff,0,0, 0xeed7, 0xffff, 0, 0,
+                                  0x9dd5, 0xbfff,0x4088,0x8000
+                                 };
     if (val!=expected[i])
       f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
@@ -1455,7 +1482,7 @@ bool MacDraftParser::readDocHeader()
   long pos=input->tell();
   f.str("");
   f << "DocHeader-1:";
-  int N=static_cast<int>(input->readULong(2));
+  auto N=static_cast<int>(input->readULong(2));
   if (N>=20) {
     MWAW_DEBUG_MSG(("MacDraftParser::readDocHeader: N seems bad\n"));
     f << "###";
@@ -1475,13 +1502,13 @@ bool MacDraftParser::readDocHeader()
   input->seek(pos+42, librevenge::RVNG_SEEK_SET);
   for (int i=0; i<6; ++i) {
     val=static_cast<int>(input->readULong(2));
-    static int const(expected[])= {0x144, 0xa, 0x152, 0xc, 0, 0 };
+    static int const expected[]= {0x144, 0xa, 0x152, 0xc, 0, 0 };
     if (val!=expected[i])
       f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
   f << "unkn1=[";
   for (int i=0; i<2; ++i) { // 0,0 or 99cc6633,99cc6633
-    long lVal=long(input->readULong(4));
+    auto lVal=long(input->readULong(4));
     if (lVal)
       f << std::hex << lVal << std::dec << ",";
     else
@@ -1545,16 +1572,16 @@ bool MacDraftParser::readDocHeader()
       f << "_,";
   }
   f << "],";
-  float dim[2];
-  for (int i=0; i<2; ++i) dim[i]=float(input->readLong(2))/8.f;
-  f << "dim?=" << MWAWVec2f(dim[1],dim[0]) << ",";
+  float coord[2];
+  for (auto &c : coord) c=float(input->readLong(2))/8.f;
+  f << "dim?=" << MWAWVec2f(coord[1],coord[0]) << ",";
   for (int i=0; i<7; ++i) { // f2=0|256, f5=256
     val=static_cast<int>(input->readLong(2));
     if (val)
       f << "f" << i+2 << "=" << val << ",";
   }
   int numPages[2];
-  for (int i=0; i<2; ++i) numPages[i]=static_cast<int>(input->readLong(2));
+  for (auto &p : numPages) p=static_cast<int>(input->readLong(2));
   if (numPages[0]!=1 || numPages[1]!=1)
     f << "numPages=" << MWAWVec2i(numPages[0], numPages[1]) << ",";
   if (numPages[0]<=0 || numPages[0]>50) {
@@ -1568,7 +1595,7 @@ bool MacDraftParser::readDocHeader()
     f << "###verti,";
   }
   int pageDim[2];
-  for (int i=0; i<2; ++i) pageDim[i]=static_cast<int>(input->readLong(2));
+  for (auto &d : pageDim) d=static_cast<int>(input->readLong(2));
   f << "page[dim]=" << MWAWVec2i(pageDim[1],pageDim[0]) << ",";
   if (pageDim[0]>=50 && pageDim[0]<=2000)
     getPageSpan().setFormLength(double(pageDim[0]*numPages[1])/72.);
@@ -1596,7 +1623,7 @@ bool MacDraftParser::readPrintInfo()
 {
   MWAWInputStreamPtr input = getInput();
   long pos=input->tell();
-  long fSz=long(input->readULong(2));
+  auto fSz=long(input->readULong(2));
   long endPos=pos+2+120;
   if (fSz!=120 || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("MacDraftParser::readPrintInfo: file seems too short\n"));
@@ -1688,12 +1715,12 @@ bool MacDraftParser::send(MacDraftParserInternal::Shape const &shape)
     size_t numShapes=m_state->m_shapeList.size();
     if (!numShapes) break;
     listener->openGroup(pos);
-    for (size_t i=0; i<shape.m_childList.size(); ++i) {
-      if (shape.m_childList[i]>=numShapes) {
+    for (auto id : shape.m_childList) {
+      if (id>=numShapes) {
         MWAW_DEBUG_MSG(("MacDraftParser::send: can not find a child\n"));
         continue;
       }
-      MacDraftParserInternal::Shape const &child=m_state->m_shapeList[shape.m_childList[i]];
+      MacDraftParserInternal::Shape const &child=m_state->m_shapeList[id];
       if (child.m_isSent) {
         MWAW_DEBUG_MSG(("MacDraftParser::send: the child is already sent\n"));
         continue;
@@ -1711,23 +1738,23 @@ bool MacDraftParser::send(MacDraftParserInternal::Shape const &shape)
       MWAW_DEBUG_MSG(("MacDraftParser::send: problem finding the shape\n"));
       break;
     }
-    MacDraftParserInternal::Shape const &obj=m_state->m_shapeList[size_t(shape.m_id-1)];
+    auto const &obj=m_state->m_shapeList[size_t(shape.m_id-1)];
     if (obj.m_type!=MacDraftParserInternal::Shape::Basic || !obj.m_isLine) {
       MWAW_DEBUG_MSG(("MacDraftParser::send: can only retrieve line label\n"));
       break;
     }
     // update the label width and recenter the label box
     MWAWVec2f lineSz=obj.m_shape.getBdBox().size();
-    MacDraftParserInternal::Shape &label=m_state->m_shapeList[size_t(shape.m_id)];
+    auto &label=m_state->m_shapeList[size_t(shape.m_id)];
     label.m_labelWidth=std::sqrt(lineSz[0]*lineSz[0]+lineSz[1]*lineSz[1]);
     MWAWVec2f decal=obj.m_shape.getBdBox().center()-box.center();
     pos.setOrigin(box[0]+decal);
-    shared_ptr<MWAWSubDocument> doc(new MacDraftParserInternal::SubDocument(*this, getInput(), shape.m_id));
+    std::shared_ptr<MWAWSubDocument> doc(new MacDraftParserInternal::SubDocument(*this, getInput(), shape.m_id));
     listener->insertTextBox(pos, doc, style);
     return true;
   }
   case MacDraftParserInternal::Shape::Text: {
-    shared_ptr<MWAWSubDocument> doc(new MacDraftParserInternal::SubDocument(*this, getInput(), shape.m_id));
+    std::shared_ptr<MWAWSubDocument> doc(new MacDraftParserInternal::SubDocument(*this, getInput(), shape.m_id));
     listener->insertTextBox(pos, doc, style);
     return true;
   }
@@ -1759,7 +1786,7 @@ bool MacDraftParser::sendBitmap(MacDraftParserInternal::Shape const &bitmap, MWA
   MWAWBox2i bitmapBox=bitmap.m_bitmapDimensionList[0];
   for (size_t i=1; i<bitmap.m_bitmapDimensionList.size(); ++i)
     bitmapBox=bitmapBox.getUnion(bitmap.m_bitmapDimensionList[i]);
-  MWAWVec2i bitmapDim=bitmapBox.size();
+  MWAWVec2i bitmapDim(bitmapBox.size());
   if (bitmapDim[0]<=0||bitmapDim[1]<=0||bitmapDim[0]*bitmapDim[1]>10000000) {
     MWAW_DEBUG_MSG(("MacDraftParser::sendBitmap: can not compute the bitmap bdbox\n"));
     return false;
@@ -1774,15 +1801,16 @@ bool MacDraftParser::sendBitmap(MacDraftParserInternal::Shape const &bitmap, MWA
   for (int r=0; r<bitmapDim[1]; ++r)  pict.setRow(r, &colors[0]);
 
   for (size_t i=0; i<bitmap.m_bitmapIdList.size(); ++i) {
-    if (m_state->m_idToBitmapMap.find(bitmap.m_bitmapIdList[i])==m_state->m_idToBitmapMap.end()) {
-      MWAW_DEBUG_MSG(("MacDraftParser::sendBitmap: can not find bitmap data %lx\n", bitmap.m_bitmapIdList[i]));
+    auto id=bitmap.m_bitmapIdList[i];
+    if (m_state->m_idToBitmapMap.find(id)==m_state->m_idToBitmapMap.end()) {
+      MWAW_DEBUG_MSG(("MacDraftParser::sendBitmap: can not find bitmap data %lx\n", id));
       continue;
     }
-    MWAWBox2i dataBox=bitmap.m_bitmapDimensionList[i];
-    MacDraftParserInternal::BitmapFileData const &data=m_state->m_idToBitmapMap.find(bitmap.m_bitmapIdList[i])->second;
+    MWAWBox2i dataBox(bitmap.m_bitmapDimensionList[i]);
+    MacDraftParserInternal::BitmapFileData const &data=m_state->m_idToBitmapMap.find(id)->second;
     if (!data.ok() || data.m_dimension[0]!=dataBox[0] || data.m_dimension.size()[0]<dataBox.size()[0] ||
         data.m_dimension.size()[1]<dataBox.size()[1]) {
-      MWAW_DEBUG_MSG(("MacDraftParser::sendBitmap: bitmap data %lx seems bad\n", bitmap.m_bitmapIdList[i]));
+      MWAW_DEBUG_MSG(("MacDraftParser::sendBitmap: bitmap data %lx seems bad\n", id));
       continue;
     }
 
@@ -1795,7 +1823,7 @@ bool MacDraftParser::sendBitmap(MacDraftParserInternal::Shape const &bitmap, MWA
       int row=r-bitmapBox[0][1];
       int wPos=dataBox[0][0]-bitmapBox[0][0];
       for (int col=dataBox[0][0]; col<dataBox[1][0];) {
-        unsigned char c=static_cast<unsigned char>(input->readULong(1));
+        auto c=static_cast<unsigned char>(input->readULong(1));
         for (int j=0, bit=0x80; j<8 ; ++j, bit>>=1) {
           if (wPos>=bitmapDim[0] || ++col>dataBox[1][0]) break;
           pict.set(wPos++, row, (c&bit) ? black : transparent);
@@ -1833,7 +1861,7 @@ bool MacDraftParser::sendText(int zId)
     MWAW_DEBUG_MSG(("MacDraftParser::sendText: can not find the text shape\n"));
     return false;
   }
-  MacDraftParserInternal::Shape const &shape=m_state->m_shapeList[size_t(zId)];
+  auto const &shape=m_state->m_shapeList[size_t(zId)];
   shape.m_isSent = true;
 
   listener->setParagraph(shape.m_paragraph);
@@ -1858,7 +1886,7 @@ bool MacDraftParser::sendText(int zId)
   while (!input->isEnd()) {
     if (input->tell()>=shape.m_textEntry.end())
       break;
-    char c = char(input->readULong(1));
+    auto c = char(input->readULong(1));
     if (c==0) {
       MWAW_DEBUG_MSG(("MacDraftParser::sendText: find char 0\n"));
       f << "#[0]";
