@@ -67,9 +67,24 @@ namespace MsWksDocumentInternal
 //! Internal: the state of a MsWksDocument
 struct State {
   //! constructor
-  State() : m_kind(MWAWDocument::MWAW_K_TEXT), m_fileHeaderSize(0),
-    m_freeZoneId(0), m_typeZoneMap(), m_entryMap(), m_hasHeader(false), m_hasFooter(false),
-    m_oleParser(), m_headerParser(), m_footerParser(), m_footnoteParser(), m_frameParserMap(), m_unparsedOlesName(), m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
+  State()
+    : m_kind(MWAWDocument::MWAW_K_TEXT)
+    , m_fileHeaderSize(0)
+    , m_freeZoneId(0)
+    , m_typeZoneMap()
+    , m_entryMap()
+    , m_hasHeader(false)
+    , m_hasFooter(false)
+    , m_oleParser()
+    , m_headerParser()
+    , m_footerParser()
+    , m_footnoteParser()
+    , m_frameParserMap()
+    , m_unparsedOlesName()
+    , m_actPage(0)
+    , m_numPages(0)
+    , m_headerHeight(0)
+    , m_footerHeight(0)
   {
   }
   //! returns a color palette
@@ -88,11 +103,11 @@ struct State {
 
   // ole data
   /** the ole parser */
-  shared_ptr<MWAWOLEParser> m_oleParser;
-  shared_ptr<MsWks4Zone> m_headerParser /**parser of the header ole*/, m_footerParser /**parser of the footer ole*/,
-             m_footnoteParser /**parser of the footnote ole*/;
+  std::shared_ptr<MWAWOLEParser> m_oleParser;
+  std::shared_ptr<MsWks4Zone> m_headerParser /**parser of the header ole*/, m_footerParser /**parser of the footer ole*/,
+      m_footnoteParser /**parser of the footnote ole*/;
   /**the frame parsers: name-> parser*/
-  std::map<std::string, shared_ptr<MsWks4Zone> > m_frameParserMap;
+  std::map<std::string, std::shared_ptr<MsWks4Zone> > m_frameParserMap;
   //! the list of unparsed OLEs
   std::vector<std::string> m_unparsedOlesName;
   //! the color palette
@@ -175,7 +190,7 @@ std::vector<MWAWColor> const &State::getPalette(int vers)
     ind--; // remove the black color
     for (int c = 0; c < 4; c++) {
       unsigned char color[3] = {0,0,0};
-      unsigned char val=static_cast<unsigned char>(251);
+      auto val=static_cast<unsigned char>(251);
       for (int i = 0; i < 10; i++) {
         val = static_cast<unsigned char>(val-17);
         if (c == 3) m_colorPalette[2][ind++]=MWAWColor(val, val, val);
@@ -200,27 +215,26 @@ std::vector<MWAWColor> const &State::getPalette(int vers)
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a MsWksDocument
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
   enum Type { Note, OLE, Zone, Text };
-  SubDocument(MsWksDocument &document, MWAWInputStreamPtr input, Type type,
-              int zoneId) :
-    MWAWSubDocument(document.m_parser, input, MWAWEntry()), m_document(document), m_type(type), m_id(zoneId) {}
-
-  //! destructor
-  virtual ~SubDocument() {}
-
-  //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const;
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
+  SubDocument(MsWksDocument &document, MWAWInputStreamPtr const &input, Type type, int zoneId)
+    : MWAWSubDocument(document.m_parser, input, MWAWEntry())
+    , m_document(document)
+    , m_type(type)
+    , m_id(zoneId)
   {
-    return !operator!=(doc);
   }
 
+  //! destructor
+  ~SubDocument() final {}
+
+  //! operator!=
+  bool operator!=(MWAWSubDocument const &doc) const final;
+
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   /** the main document */
@@ -268,7 +282,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
 bool SubDocument::operator!=(MWAWSubDocument const &doc) const
 {
   if (MWAWSubDocument::operator!=(doc)) return true;
-  SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+  auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
   if (!sDoc) return true;
   if (&m_document != &sDoc->m_document) return true;
   if (m_id != sDoc->m_id) return true;
@@ -280,9 +294,17 @@ bool SubDocument::operator!=(MWAWSubDocument const &doc) const
 ////////////////////////////////////////////////////////////
 // constructor/destructor, accessor functions...
 ////////////////////////////////////////////////////////////
-MsWksDocument::MsWksDocument(MWAWInputStreamPtr input, MWAWParser &parser) :
-  m_state(), m_parserState(parser.getParserState()), m_parser(&parser), m_parentDocument(0),
-  m_input(input), m_asciiFile(MWAWInputStreamPtr()), m_graphParser(), m_textParser3(), m_textParser4(), m_newPage(0)
+MsWksDocument::MsWksDocument(MWAWInputStreamPtr const &input, MWAWParser &parser)
+  : m_state()
+  , m_parserState(parser.getParserState())
+  , m_parser(&parser)
+  , m_parentDocument(nullptr)
+  , m_input(input)
+  , m_asciiFile(MWAWInputStreamPtr())
+  , m_graphParser()
+  , m_textParser3()
+  , m_textParser4()
+  , m_newPage(nullptr)
 {
   m_state.reset(new MsWksDocumentInternal::State());
   m_graphParser.reset(new MsWksGraph(*this));
@@ -298,13 +320,13 @@ void MsWksDocument::initAsciiFile(std::string const &name)
   m_asciiFile.open(name);
 }
 
-shared_ptr<MsWks3Text> MsWksDocument::getTextParser3()
+std::shared_ptr<MsWks3Text> MsWksDocument::getTextParser3()
 {
   if (!m_textParser3) m_textParser3.reset(new MsWks3Text(*this));
   return m_textParser3;
 }
 
-shared_ptr<MsWks4Text> MsWksDocument::getTextParser4()
+std::shared_ptr<MsWks4Text> MsWksDocument::getTextParser4()
 {
   if (!m_textParser4) m_textParser4.reset(new MsWks4Text(*this));
   return m_textParser4;
@@ -527,12 +549,11 @@ void MsWksDocument::sendTextbox(MWAWEntry const &entry, std::string const &frame
     return;
   }
 
-  MsWks4Zone *parser = 0;
+  MsWks4Zone *parser = nullptr;
   if (frame == "QHdr") parser=m_state->m_headerParser.get();
   else if (frame == "QFtr") parser=m_state->m_footerParser.get();
   else {
-    std::map<std::string, shared_ptr<MsWks4Zone> >::iterator frameIt =
-      m_state->m_frameParserMap.find(frame);
+    auto frameIt = m_state->m_frameParserMap.find(frame);
     if (frameIt != m_state->m_frameParserMap.end())
       parser = frameIt->second.get();
   }
@@ -598,19 +619,18 @@ bool MsWksDocument::createOLEZones(MWAWInputStreamPtr input)
 
   // normally,
   // MacWorks/QHdr, MacWorks/QFtr, MacWorks/QFootnotes, MacWorks/QFrm<number>
-  // MN0 (the main header)
-  std::vector<std::string> unparsed = m_state->m_oleParser->getNotParse();
+  // MN0 (the main header), MM (almost empty)
+  // MatOST/MatadorObject?/*: the picture
+  // but no metadata
+  auto unparsed = m_state->m_oleParser->getNotParse();
 
-  size_t numUnparsed = unparsed.size();
   unparsed.push_back("MN0");
 
-  for (size_t i = 0; i <= numUnparsed; i++) {
-    std::string const &name = unparsed[i];
-
+  for (auto const &name : unparsed) {
     // separated the directory and the name
     //    MatOST/MatadorObject1/Ole10Native
     //      -> dir="MatOST/MatadorObject1", base="Ole10Native"
-    std::string::size_type pos = name.find_last_of('/');
+    auto pos = name.find_last_of('/');
     std::string dir, base;
     if (pos == std::string::npos) base = name;
     else if (pos == 0) base = name.substr(1);
@@ -622,7 +642,7 @@ bool MsWksDocument::createOLEZones(MWAWInputStreamPtr input)
     if (dir == "" && base == "MN0") continue;
     bool ok = false;
     bool isFrame = false;
-    if (!ok && dir == "MacWorks") {
+    if (dir == "MacWorks") {
       ok = (base == "QHdr" || base == "QFtr" || base == "QFootnotes");
       if (!ok && strncmp(base.c_str(),"QFrm",4)==0)
         ok = isFrame = true;
@@ -638,7 +658,7 @@ bool MsWksDocument::createOLEZones(MWAWInputStreamPtr input)
       continue;
     }
 
-    shared_ptr<MsWks4Zone> newParser(new MsWks4Zone(ole, m_parserState, *m_parser, name));
+    std::shared_ptr<MsWks4Zone> newParser(new MsWks4Zone(ole, m_parserState, *m_parser, name));
     try {
       ok = newParser->createZones(false);
     }
@@ -656,8 +676,7 @@ bool MsWksDocument::createOLEZones(MWAWInputStreamPtr input)
     if (base == "QHdr") m_state->m_headerParser = newParser;
     else if (base == "QFtr") m_state->m_footerParser = newParser;
     else if (isFrame) {
-      std::map<std::string, shared_ptr<MsWks4Zone> >::iterator frameIt =
-        m_state->m_frameParserMap.find(base);
+      auto frameIt = m_state->m_frameParserMap.find(base);
       if (frameIt != m_state->m_frameParserMap.end()) {
         MWAW_DEBUG_MSG(("MsWksDocument::createOLEZones: error: oops, I already find a frame zone %s\n", base.c_str()));
       }
@@ -790,7 +809,7 @@ bool MsWksDocument::readDocumentInfo(long sz)
   pos = input->tell();
   f.str("");
   f << "DocInfo-1:";
-  int val = static_cast<int>(input->readLong(2));
+  auto val = static_cast<int>(input->readLong(2));
   if ((val & 0x0400) && vers >= 3) {
     f << "titlepage,";
     val &= 0xFBFF;
@@ -805,7 +824,7 @@ bool MsWksDocument::readDocumentInfo(long sz)
 
       long remain = debPos+100 - input->tell();
       for (long i = 0; i < remain; i++) {
-        unsigned char c = static_cast<unsigned char>(input->readULong(1));
+        auto c = static_cast<unsigned char>(input->readULong(1));
         if (c == 0) continue;
         f << std::dec << "f"<< i << "=" << static_cast<int>(c) << ",";
       }
@@ -815,7 +834,7 @@ bool MsWksDocument::readDocumentInfo(long sz)
     val = static_cast<int>(input->readULong(2)); // 0 or 8
     if (val) f << "#unkn=" << val << ",";
     int dim[2];
-    for (int i = 0; i < 2; i++) dim[i] = static_cast<int>(input->readULong(2));
+    for (auto &d : dim) d = static_cast<int>(input->readULong(2));
     f << "dim=" << dim[0] << "x" << dim[1] << ",";
     /* followed by 0 (v1) or 0|0x21|0* (v2)*/
     ascii().addPos(pos);
@@ -826,7 +845,7 @@ bool MsWksDocument::readDocumentInfo(long sz)
   }
 
   // last data ( normally 26)
-  int numData = int((endPos - input->tell())/2);
+  auto numData = int((endPos - input->tell())/2);
   for (int i = 0; i < numData; i++) {
     val = static_cast<int>(input->readLong(2));
     switch (i) {
@@ -860,7 +879,7 @@ bool MsWksDocument::readGroupHeaderFooter(bool header, int check)
   MWAWInputStreamPtr input=getInput();
   long debPos = input->tell();
 
-  long ptr = long(input->readULong(2));
+  auto ptr = long(input->readULong(2));
   if (input->isEnd()) return false;
   if (ptr) {
     if (check == 49) return false;
@@ -885,11 +904,10 @@ bool MsWksDocument::readGroupHeaderFooter(bool header, int check)
   if (!input->checkPosition(debPos+size)) return false;
 
   input->seek(debPos+6, librevenge::RVNG_SEEK_SET);
-  int N=static_cast<int>(input->readLong(2));
+  auto N=static_cast<int>(input->readLong(2));
   f << ", N=" << N;
   int dim[4];
-  for (int i = 0; i < 4; i++)
-    dim[i] = static_cast<int>(input->readLong(2));
+  for (auto &d : dim) d = static_cast<int>(input->readLong(2));
 
   MWAWBox2i box(MWAWVec2i(dim[1], dim[0]), MWAWVec2i(dim[3], dim[2]));
   if (box.size().x() < -2000 || box.size().y() < -2000 ||
@@ -897,7 +915,7 @@ bool MsWksDocument::readGroupHeaderFooter(bool header, int check)
       box.min().x() < -200 || box.min().y() < -200) return false;
   if (check == 49 && box.size().x() == 0 &&  box.size().y() == 0) return false;
   f << ", BDBox =" << box;
-  int val = static_cast<int>(input->readULong(1));
+  auto val = static_cast<int>(input->readULong(1));
   if (val) f << ", flag=" << val;
 
   input->seek(debPos+size, librevenge::RVNG_SEEK_SET);
@@ -958,7 +976,7 @@ bool MsWksDocument::readZone(MsWksDocument::Zone &zone)
   if (input->isEnd()) return false;
   long pos = input->tell();
   MWAWEntry pict;
-  int val = static_cast<int>(input->readLong(1));
+  auto val = static_cast<int>(input->readLong(1));
   input->seek(-1, librevenge::RVNG_SEEK_CUR);
   switch (val) {
   case 0: {
@@ -1015,7 +1033,7 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   input->seek(0,librevenge::RVNG_SEEK_SET);
 
   m_state->m_hasHeader = m_state->m_hasFooter = false;
-  int vers = static_cast<int>(input->readULong(4));
+  auto vers = static_cast<int>(input->readULong(4));
   switch (vers) {
   case 11:
     setVersion(4);
@@ -1053,7 +1071,7 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
     }
   }
   input->seek(1,librevenge::RVNG_SEEK_CUR);
-  int type = static_cast<int>(input->readLong(2));
+  auto type = static_cast<int>(input->readLong(2));
   switch (type) {
   // Text document
   case 1:
@@ -1080,7 +1098,7 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
   f << "FileHeader: ";
   f << "version= " << input->readULong(4);
   long dim[4];
-  for (int i = 0; i < 4; i++) dim[i] = input->readLong(2);
+  for (auto &d : dim) d = input->readLong(2);
   bool checkDatabaseFileHSize=false;
   if (dim[2] <= dim[0] || dim[3] <= dim[1]) {
     // bdbox(0,0,0,0) can appear if there is no document info, so do not consider this an error for database file
@@ -1093,9 +1111,9 @@ bool MsWksDocument::checkHeader3(MWAWHeader *header, bool strict)
     }
   }
   f << ", windowdbdbox?=(";
-  for (int i = 0; i < 4; i++) f << dim[i]<<",";
+  for (auto d : dim) f << d <<",";
   f << "),";
-  long fileHeaderSize=long(input->readULong(4));
+  auto fileHeaderSize=long(input->readULong(4));
   if (checkDatabaseFileHSize && strict) {
     if ((version()==2 && fileHeaderSize!=0x516) || (version()==3&&fileHeaderSize!=0x50))
       return false;
@@ -1173,7 +1191,7 @@ bool MsWksDocument::readDBString(long endPos, std::string &res)
   int error = 0;
   int ok = 0;
   while (input->tell() != endPos) {
-    char c = char(input->readLong(1));
+    auto c = char(input->readLong(1));
     if (c < 27 && c != '\t' && c != '\n') error++;
     else ok++;
     res += c;
@@ -1199,7 +1217,7 @@ bool MsWksDocument::readCellInFormula(MWAWCellContent::FormulaInstruction &instr
   bool ok = true;
   if (is2D) {
     bool absolute[2] = { false, false};
-    int type = static_cast<int>(input->readULong(1));
+    auto type = static_cast<int>(input->readULong(1));
     if (type & 0x80) {
       absolute[0] = true;
       type &= 0x7F;
@@ -1213,8 +1231,7 @@ bool MsWksDocument::readCellInFormula(MWAWCellContent::FormulaInstruction &instr
       ok = false;
     }
     int pos[2]= {1,0};
-    for (int i=0; i< 2; ++i)
-      pos[i] = static_cast<int>(input->readULong(1));
+    for (auto &p : pos) p = static_cast<int>(input->readULong(1));
 
     if (pos[0] < 1 || pos[1] < 0) {
       if (ok) {
@@ -1238,12 +1255,12 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
   if (pos == endPos) return false;
 
   std::stringstream f;
-  std::vector<MWAWCellContent::FormulaInstruction> &formula=content.m_formula;
+  auto &formula=content.m_formula;
   bool is2D=m_parserState->m_kind!=MWAWDocument::MWAW_K_DATABASE;
   bool ok=true;
   while (input->tell() < endPos && !input->isEnd()) {
     pos = input->tell();
-    int code = static_cast<int>(input->readLong(1));
+    auto code = static_cast<int>(input->readLong(1));
     MWAWCellContent::FormulaInstruction instr;
     bool findEnd=false;
     switch (code) {
@@ -1257,7 +1274,7 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
       break;
     }
     case 0x8: { // a number
-      int sz = static_cast<int>(input->readULong(1));
+      auto sz = static_cast<int>(input->readULong(1));
       std::string s;
       double val;
       bool isNan;
@@ -1276,7 +1293,7 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
       break;
     }
     case 0x0c: { // function
-      int v = static_cast<int>(input->readULong(1));
+      auto v = static_cast<int>(input->readULong(1));
       static char const *(listFunc) [0x41] = {
         "Abs", "Sum", "Na", "Error", "ACos", "And", "ASin", "ATan",
         "ATan2", "Average", "Choose", "Cos", "Count", "Exp", "False", "FV",
@@ -1349,10 +1366,10 @@ bool MsWksDocument::readFormula(long endPos, MWAWCellContent &content, std::stri
   f << std::dec << "unk1=[";
   // looks a little as a zone of cell ?? but this seems eroneous
   for (int i = 0; i < 2; i++) {
-    int v = static_cast<int>(input->readULong(1));
+    auto v = static_cast<int>(input->readULong(1));
 
-    int n0 = static_cast<int>(input->readULong(1));
-    int n1 = static_cast<int>(input->readULong(1));
+    auto n0 = static_cast<int>(input->readULong(1));
+    auto n1 = static_cast<int>(input->readULong(1));
     if (i == 1) f << ":";
     f << n0 << "x" << n1;
     if (v) f << "##v";
